@@ -46,7 +46,7 @@ type ControlReport struct {
 	RuleReports          []RuleReport `json:"ruleReports"`
 	Remediation          string       `json:"remediation"`
 	Description          string       `json:"description"`
-	Score                float32      `json:"score,omitempty"`
+	Score                float32      `json:"score"`
 	BaseScore            float32      `json:"baseScore,omitempty"`
 	ARMOImprovement      float32      `json:"ARMOImprovement,omitempty"`
 }
@@ -101,12 +101,11 @@ type PolicyRule struct {
 // Control represents a collection of rules which are combined together to single purpose
 type Control struct {
 	armotypes.PortalBase `json:",inline"`
-	ControlID            string `json:"id"`
-
-	CreationTime string       `json:"creationTime"`
-	Description  string       `json:"description"`
-	Remediation  string       `json:"remediation"`
-	Rules        []PolicyRule `json:"rules"`
+	ControlID            string       `json:"id"`
+	CreationTime         string       `json:"creationTime"`
+	Description          string       `json:"description"`
+	Remediation          string       `json:"remediation"`
+	Rules                []PolicyRule `json:"rules"`
 	// for new list of  rules in POST/UPADTE requests
 	RulesIDs *[]string `json:"rulesIDs,omitempty"`
 }
